@@ -25,7 +25,7 @@ package MongoDB::Error;
 
 use version;
 
-our $VERSION = 'v1.1.0'; # TRIAL
+our $VERSION = 'v1.1.1'; # TRIAL
 
 use Moo;
 use Carp;
@@ -304,7 +304,7 @@ MongoDB::Error - MongoDB Driver Error classes
 
 =head1 VERSION
 
-version v1.1.0
+version v1.1.1
 
 =head1 SYNOPSIS
 
@@ -548,7 +548,19 @@ The following error code constants are automatically exported by this module.
 This is a very, very small subset of error codes possible from the server,
 but covers some of the more common ones seen by drivers.
 
-B<Note>: only C<MongoDB::DatabaseError> objects have a C<code> attribute.
+B<Note>:
+
+=over 4
+
+=item *
+
+Only C<MongoDB::DatabaseError> objects have a C<code> attribute.
+
+=item *
+
+The database uses multiple write concern error codes.  The driver maps them all to WRITE_CONCERN_ERROR for consistency and convenience.
+
+=back
 
 =head1 AUTHORS
 
