@@ -19,7 +19,7 @@ package MongoDB::Op::_FindAndUpdate;
 # Encapsulate find_and_update operation; atomically update and return doc
 
 use version;
-our $VERSION = 'v1.1.0'; # TRIAL
+our $VERSION = 'v1.1.1'; # TRIAL
 
 use Moo;
 
@@ -123,6 +123,16 @@ sub execute {
         die $_ unless $_ eq 'No matching object found';
     };
 
+    # findAndModify returns ok:1 even for write concern errors, so 
+    # we must check and throw explicitly
+    if ( $result->{writeConcernError} ) {
+        MongoDB::WriteConcernError->throw(
+            message => $result->{writeConcernError}{errmsg},
+            result  => $result,
+            code    => WRITE_CONCERN_ERROR,
+        );
+    }
+
     return $result->{value} if $result;
     return;
 }
