@@ -25,7 +25,7 @@ use warnings;
 package MongoDB::_Link;
 
 use version;
-our $VERSION = 'v1.1.0'; # TRIAL
+our $VERSION = 'v1.1.1'; # TRIAL
 
 use Moo;
 use Errno qw[EINTR EPIPE];
@@ -399,7 +399,12 @@ sub read {
             }
         }
 
-        $len ||= unpack( P_INT32, $msg );
+        if ( !defined $len ) {
+            $len = unpack( P_INT32, $msg );
+            MongoDB::ProtocolError->throw(
+                qq/Server reply of size $len exceeds maximum of / . $self->{max_message_size_bytes} )
+              if $len > $self->max_message_size_bytes;
+        }
         last unless length($msg) < $len;
     }
 
